@@ -108,7 +108,8 @@ def index(request):
         if form.is_valid():
             author = None if request.user.is_anonymous() else request.user
             repo = Repository(author=author, name=form.cleaned_data['name'], on_index=form.cleaned_data['on_index'],
-                              archive_type=form.cleaned_data['archive_type'])
+                              archive_type=form.cleaned_data['archive_type'],
+                              is_private=form.cleaned_data['is_private'])
             repo.save()
             for group in form.cleaned_data['admin_group']:
                 repo.admin_group.add(group)
@@ -137,7 +138,6 @@ def modify_repository(request, rid):
     class RepositoryUpdateForm(forms.Form):
         name = forms.CharField(max_length=80, label=_('Repository name'), validators=[repo_name_validator])
         on_index = forms.BooleanField(label=_('Display on index for everybody?'), initial=True, required=False)
-        is_public = forms.BooleanField(label=_('Can these packages be replicated?'), initial=False, required=False)
         is_private = forms.BooleanField(label=_('Must downloads be authenticated?'), initial=False, required=False)
         states = forms.CharField(label=_('Possible states'), initial='dev qualif prod',
                                  help_text=_('Please separate values by spaces'),
@@ -158,7 +158,6 @@ def modify_repository(request, rid):
             repo.name = form.cleaned_data['name']
             repo.on_index = form.cleaned_data['on_index']
             repo.is_private = form.cleaned_data['is_private']
-            repo.is_public = form.cleaned_data['is_public']
             repo.save()
             repo.admin_group.clear()
             for group in form.cleaned_data['admin_group']:
@@ -172,7 +171,7 @@ def modify_repository(request, rid):
             messages.info(request, _('The repository %(repo)s has been modified.') % {'repo': repo.name})
             return HttpResponseRedirect(reverse('moneta.core.views.index'))
     else:
-        form = RepositoryUpdateForm(initial={'name': repo.name, 'on_index': repo.on_index, 'is_public': repo.is_public,
+        form = RepositoryUpdateForm(initial={'name': repo.name, 'on_index': repo.on_index,
                                              'is_private': repo.is_private,
                                              'reader_group': list(repo.reader_group.all()),
                                              'states': ' '.join([x.name for x in repo.archivestate_set.all()]),
